/* eslint-disable eqeqeq */
import React, { useState, useEffect } from 'react';
import '../../styles/profile/Profile.css';
import Button from '../utility/Button';
import ThreadList from '../thread/ThreadList';
import axios from 'axios';
import AuthService from '../../helpers/services/auth.service';
import { API_URL } from '../../config/keys';
import Pagination from '../thread/Pagination';

export default function Profile(props) {
  const { params } = props.match;
  const profileUsername = params.user;
  const currentPage = params.pageNumber;

  const username = AuthService.getCurrentUsername();

  const [user, setUser] = useState({
    id: '',
    name: '',
    username: '',
  });
  const [usersThreads, setUsersThreads] = useState([]);
  const [totalItems, setTotalItems] = useState(0);

  useEffect(() => {
    async function fetch(profileUsername) {
      // Fetch current user
      const getUser = await axios.get(
        `${API_URL}/users/name/${profileUsername}`
      );
      setUser(getUser?.data?.data);

      const responseThreads = await axios.get(
        `${API_URL}/threads/pages/user/${profileUsername}/?page=${currentPage}`
      );
      const { data } = responseThreads;
      setUsersThreads(data?.data);
      setTotalItems(data?.metadata?.total_data);
    }
    fetch(profileUsername);
  }, [currentPage, profileUsername]);

  function switchPage(pageNumber) {
    props.history.push(`/profile/${profileUsername}/page/${pageNumber}`);
    window.location.reload();
  }

  return (
    <div className="profileContainer">
      <div className="header">
        <h1>
          <b>Profile</b>
        </h1>
      </div>
      <div className="profile_section">
        <div className="userIcon">
          {user.picture == 'None' && <i className="far fa-user-circle" />}
          {user.picture != 'None' && (
            <img alt="profile pic" src={user.picture} />
          )}
        </div>
        <h2>
          <b>{user.username}</b>
        </h2>
        {username == profileUsername && (
          <Button text="Edit Profile" color="orange" url="profile/update" />
        )}
      </div>
      <div className="my_threads_section">
        <div className="sub_header_my_threads">
          <h3>
            {username == profileUsername && (
              <b>Your threads</b>
            )}
            {username != profileUsername && (
              <b>{user.username}s threads</b>
            )}
          </h3>

          {username == profileUsername && (
            <Button text="Create Thread" color="orange" url="create/thread" />
          )}
        </div>
        {totalItems == 0 && username == profileUsername && (
            <p>You don't have any thread. Why don't you make one?</p>
        )}
        {totalItems == 0 && username != profileUsername && (
            <p>{user.username} doesn't have any threads.</p>
        )}

        {totalItems != 0 && <ThreadList thread={usersThreads} />}
        {totalItems != 0 && (
          <div className="paginationContainer">
            <Pagination
              activePage={currentPage}
              totalItems={totalItems}
              switchPage={switchPage}
            />
          </div>
        )}
      </div>
    </div>
  );
}
