import axios from 'axios';
import React, { useState, useEffect } from 'react';
import { useInput } from '../../helpers/hooks/input-hook';
import authHeader from '../../helpers/services/authHeader.service';
import { API_URL } from '../../config/keys';
import '../../styles/thread/EditThread.css';

export default function EditThread(props) {
  const { history } = props;

  const back = () => {
    history.goBack();
  };

  const redirect = (path) => {
    history.push(path);
  };

  const threadId = props.match.params.thread;

  const {
    value: title,
    setValue: setTitle,
    bind: bindTitle,
    reset: resetTitle,
  } = useInput('');
  const {
    value: body,
    setValue: setBody,
    bind: bindBody,
    reset: resetBody,
  } = useInput('');
  const {
    value: topicId,
    setValue: setTopicId,
    bind: bindTopicId,
    reset: resetTopicId,
  } = useInput(0);

  const [listTopic, setlistTopic] = useState([]);
  const [point, setPoint] = useState(0);
  const [message, setMessage] = useState('');

  useEffect(() => {
    async function getListTopic() {
      const allTopic = await (await axios.get(`${API_URL}/topics`))?.data?.data;
      setlistTopic(allTopic);
    }

    async function getDetailThread(threadId) {
      // Grab thread detail
      const { title, content, topic_id, points } = await (
        await axios.get(`${API_URL}/threads/${threadId}`)
      ).data?.data;
      setTitle(title);
      setBody(content);
      setTopicId(topic_id);
      setPoint(points);
    }
    getListTopic();
    getDetailThread(threadId);
  }, [setBody, setTitle, setTopicId, threadId]);

  const handleSubmit = async (event) => {
    event.preventDefault();
    try {
      const thisThread = await axios.put(
        `${API_URL}/threads/${threadId}`,
        {
          thread: {
            content: body,
            points: point,
            title: title,
            topic_id: topicId,
          },
        },
        {
          headers: authHeader(),
        }
      );
      const { data } = thisThread?.data;
      redirect(`/topic/${data?.topic_name}/${data?.id}/page/1`);
    } catch (error) {
      setMessage('Thread title already exist in the selected topic');
    }
    resetBody();
    resetTitle();
    resetTopicId();
  };

  return (
    <div className="editThreadContainer">
      <div className="back" onClick={back}>
        <i className="fas fa-angle-left"></i>
        <h5>Back</h5>
      </div>
      <div className="header">
        <h1>
          <b>Edit a Thread</b>
        </h1>
      </div>
      <div className="form_section">
        <div>
          {message && (
            <div>
              <div className="alert alert-danger" role="alert">
                {message}
              </div>
            </div>
          )}
          <form onSubmit={handleSubmit}>
            <div className="form_container">
              <label for="title">Title</label>
              <input
                type="text"
                className="title"
                name="title"
                placeholder="Your threads title"
                required="false"
                {...bindTitle}
              />
              <label>Topic</label>
              <select
                className="topic"
                name="topic"
                required="false"
                {...bindTopicId}
              >
                <option value="" />
                {listTopic.map((topic) => (
                  <option value={topic.id}>{topic.name}</option>
                ))}
              </select>
              <label for="body">Body</label>
              <textarea
                className="body"
                name="body"
                placeholder="Tulis"
                required="false"
                {...bindBody}
              />
              <div className="buttonContainer">
                <input type="submit" className="buttonSubmit" value="Edit Thread" />
              </div>
            </div>
          </form>
        </div>
      </div>
    </div>
  );
}
