/* eslint-disable eqeqeq */
import '../../styles/thread/Post.css';
import axios from 'axios';
import AuthService from '../../helpers/services/auth.service';
import authHeader from '../../helpers/services/authHeader.service';
import React, { useState, useEffect } from 'react';
import { loggedIn } from '../../helpers/services/loggedIn.service';
import { translate } from '../../helpers/time-util';
import { API_URL } from '../../config/keys';
import Button from '../utility/Button';
import { Link } from 'react-router-dom';

export default function Post(props) {
  const { content } = props;
  const checkType = props.type === 'thread' ? 'threads' : 'post';
  const contents = checkType === 'threads' ? content.content : content.message;

  const [points, setPoints] = useState(0);
  const [isLiked, setIsLiked] = useState(false);
  const [user, setUser] = useState({
    id: '',
    name: '',
    username: '',
  });

  const deletePost = async (username) => {
    try {
      await axios.delete(`${API_URL}/${checkType}/${content.id}`, {
        headers: authHeader(),
      });
      if (checkType === 'threads') props.redirect(`/profile/${username}/1`);
      else window.location.reload();
    } catch (error) {}
  };

  useEffect(() => {
    const fetch = async () => {
      try {
        setPoints(content.points);
        if (content.username != '') {
          const getUser = await axios.get(
            `${API_URL}/users/name/${content.username}`
          );
          setUser(getUser?.data?.data);
        }
        await axios.get(`${API_URL}/${checkType}/checklike/${content.id}`, {
          headers: authHeader(),
        });
        setIsLiked(true);
      } catch (error) {
        setIsLiked(false);
      }
    };
    fetch();
  }, [checkType, content.id, content.points, content.username]);

  const handleLike = async () => {
    try {
      await axios.get(`${API_URL}/${checkType}/checklike/${content.id}`, {
        headers: authHeader(),
      });
      await axios.post(
        `${API_URL}/${checkType}/dislike/${content.id}`,
        {},
        {
          headers: authHeader(),
        }
      );
      setPoints(points - 1);
      setIsLiked(false);
    } catch (error) {
      await axios.post(
        `${API_URL}/${checkType}/like/${content.id}`,
        {},
        {
          headers: authHeader(),
        }
      );
      setPoints(points + 1);
      setIsLiked(true);
    }
  };

  const time = translate(content.inserted_at);

  return (
    <div id="post">
      <div id="postHeader">
        <div id="headerData">
          <div className="userImage">
            {user.picture == 'None' && <i className="far fa-user-circle" />}
            {user.picture != 'None' && <img alt="profile" src={user.picture} />}
          </div>
          <div className="creator">
            <p>
              By{' '}
              <Link to={`/profile/${content.username}/1`}>
                {content.username}
              </Link>{' '}
              - {time}{' '}
            </p>
          </div>
        </div>

        <div id="headerButton">
          <div className="buttonContainer">
            {content.user_id == AuthService.getCurrentUserId() && (
              <div>
                <Button
                  type="button"
                  text="Edit"
                  color="none-green"
                  url={`thread/edit/${content.id}`}
                />
                <button
                  type="button"
                  className="deleteButton"
                  onClick={() => deletePost(user.username)}
                >
                  Delete
                </button>
              </div>
            )}
          </div>
        </div>
      </div>
      <div id="postContent">
        {props.type == 'thread' && <h1 id="judul">{content.title}</h1>}
        <p id="isi">{contents}</p>
        <div className="likeSection">
          {loggedIn && (
            <button className="likeButton" onClick={handleLike}>
              <i className={`far fa-thumbs-up ${isLiked ? 'active' : 'inactive'}`} />
            </button>
          )}
          <div className="pointContainer">
            <div className="point">
              <p>{points} - likes</p>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
}
