/* eslint-disable eqeqeq */
import axios from 'axios';
import React, { useState } from 'react';
import { useInput } from '../../helpers/hooks/input-hook';
import '../../styles/topic/CreateTopicForm.css';
import authHeader from '../../helpers/services/authHeader.service';
import { API_URL } from '../../config/keys';
import AuthService from '../../helpers/services/auth.service';
import { loggedIn } from '../../helpers/services/loggedIn.service';

export default function CreateTopicForm(props) {
  const isAdmin = loggedIn ? AuthService.getCurrentUser().data.role : "unregistered";

  if (isAdmin != "admin") {
    props.history.push("/page/1")
  }

  const { value: name, bind: bindName, reset: resetName } = useInput('');
  const [message, setMessage] = useState('');

  const handleSubmit = async (event) => {
    event.preventDefault();

    try {
      await axios.post(
        `${API_URL}/topics`,
        {
          topic: {
            name: name,
          },
        },
        {
          headers: authHeader(),
        }
      );
      props.history.push(`/topic`);
    } catch (error) {}
    resetName();
    setMessage('There is already a topic with this name.');
  };

  const back = () => {
    props.history.goBack();
  };

  return (
    <div className="createTopicFormContainer">
      <div className="back" onClick={back}>
        <i className="fas fa-angle-left"></i>
        <h5>Back</h5>
      </div>
      <div className="header">
        <h1>
          <b>Create a Topic</b>
        </h1>
      </div>
      {message && (
        <div>
          <div className="alert alert-danger" role="alert">
            {message}
          </div>
        </div>
      )}
      <form onSubmit={handleSubmit}>
        <div className="form_container">
          <label for="title">Topic Name</label>
          <input
            type="text"
            name="title"
            className="title"
            placeholder="Your topic name"
            required="true"
            {...bindName}
          />
          <div className="buttonContainer">
            <input 
              type="submit" 
              value="Create Topic"
              className="buttonSubmit" />
          </div>
        </div>
      </form>
    </div>
  );
}
