/* eslint-disable eqeqeq */
import React, { useEffect, useState } from 'react';
import axios from 'axios';
import ThreadList from '../thread/ThreadList';
import { loggedIn } from '../../helpers/services/loggedIn.service';
import { API_URL } from '../../config/keys';
import '../../styles/topic/Topic.css';
import Button from '../utility/Button';
import Pagination from '../thread/Pagination';
import AuthService from '../../helpers/services/auth.service';
import authHeader from '../../helpers/services/authHeader.service';

export default function Topic(props) {
  const { params } = props.match;
  const currentPage = params.pageNumber;
  const topicParam = params.topic;
  const isAdmin = loggedIn ? AuthService.getCurrentUser().data.role : "unregistered";

  const [threads, setThreads] = useState([]);
  const [totalItems, setTotalItems] = useState(0);

  useEffect(() => {
    const fetch = async () => {
      const responseTopics = await axios.get(`${API_URL}/topics`);
      const topicId = responseTopics?.data?.data?.find(
        (topic) => topic.name === topicParam
      )?.id;

      const responseThreads = await axios.get(
        `${API_URL}/threads/pages/topic/${topicId}/?page=${currentPage}`
      );
      const { data } = responseThreads;
      setThreads(data?.data);
      setTotalItems(data?.metadata?.total_data);
    };
    fetch();
  }, [currentPage, topicParam]);

  function switchPage(pageNumber) {
    props.history.push(`/topic/${topicParam}/page/${pageNumber}`);
    window.location.reload();
  }

  const deleteTopic = async () => {
    try {
      await axios.delete(`${API_URL}/topics/${topicParam}`, {
        headers: authHeader(),
      });
      props.history.push(`/topic`)
    } catch (error) {}
  };

  return (
    <div className="topicContainer">
      <div className="header">
        <h1>
          <b>Topic: {topicParam}</b>
        </h1>
        {loggedIn && (
          <Button 
            text="Create Thread" 
            color="orange" 
            url="create/thread" />
        )}
        {loggedIn && isAdmin == "admin" && (
          <button
            type="button"
            className="deleteTopicButton"
            onClick={() => deleteTopic()}
          >
          Delete This Topic
          </button>
        )}
      </div>
      <div className="list_threads_section">
        {totalItems == 0 && (
          <p>There are no threads with this topic yet.</p>
        )}
        {totalItems != 0 && (
          <ThreadList thread={threads} />
        )}
        {totalItems != 0 && (
          <div className="paginationContainer">
            <Pagination
              activePage={currentPage}
              totalItems={totalItems}
              switchPage={switchPage}
            />
          </div>
        )}
      </div>
    </div>
  );
}
