import React from 'react';
import { ReactComponent as DiskuyLogo } from '../../images/Logo.svg';
import '../../styles/utility/Navbar.css';
import { useState } from 'react';
import AuthService from '../../helpers/services/auth.service';
import { useInput } from '../../helpers/hooks/input-hook';
import { Link, withRouter } from 'react-router-dom';

const Navbar = (props) => {
  const [loggedIn, setLoggedIn] = useState(AuthService.getCurrentUser() && 1);
  const { value: search, bind: bindSearch, reset: resetSearch } = useInput('');

  const handleLogout = () => {
    AuthService.logout();
    setLoggedIn(false);
    window.location.reload();
  };

  const handleSearch = (event) => {
    event.preventDefault();
    props.history.push(`/search/${search}/1`);
    resetSearch();
  };
  return (
    <nav
      id="navbar"
      className="navbar navbar-expand-lg navbar-light position-sticky fixed-top"
    >
      <div className="navbar-brand">
        <div className="d-flex align-items-center">
          <Link to="/page/1">
            <DiskuyLogo />
          </Link>
        </div>
      </div>
      <i
        className="fas fa-ellipsis-v navbar-toggler"
        data-toggle="collapse"
        data-target="#navbarSupportedContent"
        aria-controls="navbarSupportedContent"
        aria-expanded="false"
        aria-label="Toggle navigation"
      />
      <div className="collapse navbar-collapse" id="navbarSupportedContent">
        <form
          className="form-inline my-2 my-lg-0 ml-auto"
          onSubmit={handleSearch}
        >
          <input
            className="form-control mr-sm-2"
            placeholder="Search thread"
            aria-label="Search"
            required={false}
            {...bindSearch}
          />
          <button className="btn my-2 my-sm-0 search" type="submit">
            <i className="fas fa-search" />
          </button>
        </form>
        <ul className="navbar-nav ml-auto">
          <li className="nav-item mr-auto">
            <Link to="/page/1" className="nav-link">
              <b>Threads</b>
            </Link>
          </li>
          <li className="nav-item mr-auto">
            <Link to="/topic" className="nav-link">
              <b>Topics</b>
            </Link>
          </li>
          {loggedIn && (
          <li className="nav-item mr-auto">
            <Link
              to={`/profile/${AuthService.getCurrentUsername()}/1`}
              className="nav-link"
            >
              <b>Profile</b>
            </Link>
          </li>
          )}
          {loggedIn ? (
            <li className="nav-item mr-auto" onClick={handleLogout}>
              <Link to="/login" className="nav-link">
                <b>Logout</b>
              </Link>
            </li>
          ) : (
            <li className="nav-item mr-auto">
              <Link to="/login" className="nav-link">
                <b>Login</b>
              </Link>
            </li>
          )}
        </ul>
      </div>
    </nav>
  );
};

export default withRouter(Navbar);
